package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,``@$!````L!X```````!``````````%C!````
M````0P```$``.``)`$``&0`8``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````E`````````"4``````````0`````````!````
M!0```````````````````````````````````)BC````````F*,`````````
M0`````````$````&````T+L```````#0^P```````-#[````````@`0`````
M``"H!`````````!``````````@````8```#@NP```````.#[````````X/L`
M``````#P`0```````/`!````````"``````````$````!````&`"````````
M8`(```````!@`@```````$0`````````1``````````$`````````%#E=&0$
M````,)P````````PG````````#"<````````[`````````#L``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````-"[````````T/L```````#0^P``
M`````#`$````````,`0````````!`````````"]L:6(V-"]L9"UL:6YU>"UL
M;V]N9V%R8V@M;'`V-&0N<V\N,0`````$````%`````,```!'3E4`IZA.N#">
M/VCW/U8)*ZH1JJR8VC$$````$`````$```!'3E4```````4````3````````
M```````1````2@````0````(````(!`0``5`!(`H```$@(8`A(*)``()(`0(
MB(`00;H``@@`````2@```$T```!0````40````````!9````6@````````!<
M````70````````!>````7P```&$``````````````&[%WQ_.WD<M:W^:?"[%
MF[;49-1\(?_D#MEQ6!SB1\8!L@&+;ZQ+X\!"^M>'PN4_++KCDGSZH6Q@F4_#
MFV>OS&9"1=7LB0=PTS-BV^T5C"7,?ZF<F^"G`@IK&IY0H^#[20``````````
M`````````````````````````````````P`,`,`<````````````````````
M`````P`-`+!:`````````````````````````P`/`""=````````````````
M`````````P`4`````0```````````````````````P`5`$@``0``````````
M`````````````P`6`%```0````````````````!F`@``$@``````````````
M``````````#5````$@````````````````````````#4`0``$@``````````
M``````````````"'````$@````````````````````````!.`0``$@``````
M``````````````````#,`@``$0````````````````````````#K````$@``
M``````````````````````"R`@``$0````````````````````````"V`0``
M$@````````````````````````#;`0``$@````````````````````````"*
M`@``$@````````````````````````!0`@``$@``````````````````````
M```<`0``$@`````````````````````````,`0``$@``````````````````
M``````#^````$@````````````````````````"(`0``$@``````````````
M```````````!````(`````````````````````````!L`0``$@``````````
M``````````````#L`0``$@`````````````````````````=````(```````
M```````````````````A`@``$@````````````````````````!M`@``$@``
M```````````````````````"`@``$@````````````````````````"5`0``
M$@`````````````````````````W````$@````````````````````````"?
M`0``$@````````````````````````!4````%@``````````````````````
M```^`0``$@````````````````````````!G````$@``````````````````
M``````"^`0``$@````````````````````````#$````$@``````````````
M``````````!X````$@`````````````````````````W`@``$@``````````
M``````````````#:````$@````````````````````````"O`0``$@``````
M``````````````````!)`@``$0````````````````````````"H````$@``
M``````````````````````!E`0``$@````````````````````````"6`P``
M$@````````````````````````#%`0``$@````````````````````````#[
M`0``$@`````````````````````````P`@``$@``````````````````````
M``"1`@``$@`````````````````````````P`0``$@``````````````````
M``````"H`@``$@````````````````````````#?````$@``````````````
M``````````!\`@``$@````````````````````````!U`@``$@``````````
M``````````````"3````$@````````````````````````!7`@``(@``````
M``````````````````!9`0``$@````````````````````````"F`0``$@``
M``````````````````````"B`@``$@````````````````````````#A`0``
M$@````````````````````````"W````$0`````````````````````````+
M`@``$@````````````````````````"Z`@``$@``````````````````````
M```O`@``$@````````````````````````"#`@``$@``````````````````
M```````E`0``$@````````````````````````!%````$@``````````````
M``````````!W`0``$@`````````````````````````3`@``$@``````````
M``````````````#F`0``$@````````````````````````"-`0``$@``````
M``````````````````"P`@``$0````````````````````````#-`0``$@``
M``````````````````````"?`P``$@`,`/@]````````&`$```````#G`P``
M$@`,`"@U````````>`8```````!$`@``$@`,`,`<````````[`$````````6
M`P``$@`,`-`H````````!``````````T`P``$@`,`*`[````````5`(`````
M```-!```$@`,`-@H````````9`(```````#-`P``$``6`%```0``````````
M```````G`P``$@`,`$`K````````.`````````!*`P``$@`,`*@Q````````
M9`````````"K`P``$0`-`+!:````````!`````````"Z`P``$@`,`!!6````
M````?`$```````#%`P``$@`,`-@G````````(`````````#B`P``$``6`'@`
M`0````````````````#[`P``$@`,`#`T````````]``````````D!```$@`,
M`!`R````````9`````````!N`P``$@`,`'@K````````E`$```````#T`P``
M$``5`%```0`````````````````:!```$0`4`$```0``````"`````````#2
M`P``$@`,`+`>````````8`````````#9`P``$@`,`*!5````````<```````
M``"$`P``$@`,``@T````````)`````````!8`P``$@`,`/@G````````V```
M``````!Z`P``$@`,`)!7````````"`,````````L!```$@`,`!`M````````
ME`0`````````7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%])5$U?<F5G
M:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET
M,P!03%]C=7)R96YT7V-O;G1E>'0`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O
M;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L
M7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!P97)L
M7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?
M<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R
M;%]D97-T<G5C=`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A
M9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!?7W-T86-K7V-H:U]F86EL`&5X:70`
M;'-E96LV-`!R96%D9&ER-C0`<W1R9'5P`&-L;W-E9&ER`&]P96XV-`!S=')R
M8VAR`'5N;&EN:P!M96UM;W9E`'-T<G1O:P!S=')L96X`<FUD:7(`<F5A9`!M
M:V1I<@!?7W9F<')I;G1F7V-H:P!G971P:60`<F5A9&QI;FL`<F5A;&QO8P!?
M7W-P<FEN=&9?8VAK`%]?9G!R:6YT9E]C:&L`;'-T870V-`!?7VQI8F-?<W1A
M<G1?;6%I;@!S=&1E<G(`;65M8VAR`%]?8WAA7V9I;F%L:7IE`'-T<F-H<@!O
M<&5N9&ER`&=E='5I9`!A8V-E<W,`;65M8W!Y`'-T<F-M<`!?7V5R<FYO7VQO
M8V%T:6]N`&%B;W)T`'-T<FYC;7``7U]E;G9I<F]N`%]?<F5G:7-T97)?871F
M;W)K`%]?<W1A8VM?8VAK7V=U87)D`&QI8G!E<FPN<V\N-2XT,`!L:6)C+G-O
M+C8`;&0M;&EN=7@M;&]O;F=A<F-H+6QP-C1D+G-O+C$`<&%R7V-U<G)E;G1?
M97AE8P!P87)?8F%S96YA;64`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E
M;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE`'-H
M85]F:6YA;`!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU
M<`!?24]?<W1D:6Y?=7-E9`!S:&%?=7!D871E`'AS7VEN:70`7U]B<W-?<W1A
M<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S971U
M<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7V1I90!P87)?
M:6YI=%]E;G8`1TQ)0D-?,BXS-@````````````````````(``0`"``$``0`#
M``$``@`"``(``@`"``$``0`!``(``0`!``(``0`"``(``@`"``$``@`!``$`
M`0`"``$``0`"``(``@`"``$``@`"``(``@`"``(``0`"``$``@`"``$``@`!
M``(``@`"``$``@`"``(``@`!``$``@`"``(``@`"``(``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!`/@"```0
M````(````+:1E@8```,`.00````````!``$`[@(``!``````````MI&6!@``
M`@`Y!````````-#[`````````P`````````H(````````-C[`````````P``
M``````#0'P```````!```0```````P`````````07````````!@``0``````
M`P````````!X7@```````"```0```````P````````"`7@```````"@``0``
M`````P````````"(7@```````#```0```````P````````"07@```````$``
M`0```````P````````"87@```````$@``0```````P````````!(``$`````
M`*C_`````````@````P``````````````+#_`````````@````T`````````
M`````+C_`````````@````X``````````````,#_`````````@```!<`````
M`````````,C_`````````@```!H``````````````-#_````````"P```"$`
M`````````````-C_`````````@```"(``````````````.#_`````````@``
M`",``````````````.C_`````````@```"H``````````````/#_````````
M`@```#@``````````````/C_`````````@```#T``````````````.#]````
M````!0````<``````````````.C]````````!0````@``````````````/#]
M````````!0````D``````````````/C]````````!0````H`````````````
M``#^````````!0````L```````````````C^````````!0````\`````````
M`````!#^````````!0```!```````````````!C^````````!0```!$`````
M`````````"#^````````!0```!(``````````````"C^````````!0```!,`
M`````````````##^````````!0```!0``````````````#C^````````!0``
M`!4``````````````$#^````````!0```!8``````````````$C^````````
M!0```!@``````````````%#^````````!0```!D``````````````%C^````
M````!0```!L``````````````&#^````````!0```!P``````````````&C^
M````````!0```!T``````````````'#^````````!0```!X`````````````
M`'C^````````!0```!\``````````````(#^````````!0```"``````````
M`````(C^````````!0```"0``````````````)#^````````!0```"4`````
M`````````)C^````````!0```"8``````````````*#^````````!0```"<`
M`````````````*C^````````!0```"@``````````````+#^````````!0``
M`"D``````````````+C^````````!0```"L``````````````,#^````````
M!0```"P``````````````,C^````````!0```"T``````````````-#^````
M````!0```"X``````````````-C^````````!0```"\``````````````.#^
M````````!0```#```````````````.C^````````!0```#$`````````````
M`/#^````````!0```#(``````````````/C^````````!0```#,`````````
M``````#_````````!0```#0```````````````C_````````!0```#4`````
M`````````!#_````````!0```#8``````````````!C_````````!0```#<`
M`````````````"#_````````!0```#@``````````````"C_````````!0``
M`#D``````````````##_````````!0```#H``````````````#C_````````
M!0```#L``````````````$#_````````!0```#P``````````````$C_````
M````!0```#X``````````````%#_````````!0```#\``````````````%C_
M````````!0```$```````````````&#_````````!0```$$`````````````
M`&C_````````!0```$(``````````````'#_````````!0```$,`````````
M`````'C_````````!0```$0``````````````(#_````````!0```$4`````
M`````````(C_````````!0```$8``````````````)#_````````!0```$<`
M`````````````)C_````````!0```$D`````````````````````````S@$`
M'*V]$0#/P=(HK5'_`LS!T@*M!44`C"'`*.`!`$S/`0`<[X'2*.T!`$P``$`#
MSP$`'.]ATBCM`0!,``!``\\!`!SO0=(H[0$`3```0`//`0`<[R'2*.T!`$P`
M`$`#SP$`'.\!TBCM`0!,``!``\\!`!SOX=$H[0$`3```0`//`0`<[\'1*.T!
M`$P``$`#SP$`'.^AT2CM`0!,``!``\\!`!SO@=$H[0$`3```0`//`0`<[V'1
M*.T!`$P``$`#SP$`'.]!T2CM`0!,``!``\\!`!SO(=$H[0$`3```0`//`0`<
M[P'1*.T!`$P``$`#SP$`'._AT"CM`0!,``!``\\!`!SOP=`H[0$`3```0`//
M`0`<[Z'0*.T!`$P``$`#SP$`'.^!T"CM`0!,``!``\\!`!SO8=`H[0$`3```
M0`//`0`<[T'0*.T!`$P``$`#SP$`'.\AT"CM`0!,``!``\\!`!SO`=`H[0$`
M3```0`//`0`<[^'/*.T!`$P``$`#SP$`'._!SRCM`0!,``!``\\!`!SOH<\H
M[0$`3```0`//`0`<[X'/*.T!`$P``$`#SP$`'.]ASRCM`0!,``!``\\!`!SO
M0<\H[0$`3```0`//`0`<[R'/*.T!`$P``$`#SP$`'.\!SRCM`0!,``!``\\!
M`!SOX<XH[0$`3```0`//`0`<[\'.*.T!`$P``$`#SP$`'.^ASBCM`0!,``!`
M`\\!`!SO@<XH[0$`3```0`//`0`<[V'.*.T!`$P``$`#SP$`'.]!SBCM`0!,
M``!``\\!`!SO(<XH[0$`3```0`//`0`<[P'.*.T!`$P``$`#SP$`'._AS2CM
M`0!,``!``\\!`!SOP<TH[0$`3```0`//`0`<[Z'-*.T!`$P``$`#SP$`'.^!
MS2CM`0!,``!``\\!`!SO8<TH[0$`3```0`//`0`<[T'-*.T!`$P``$`#SP$`
M'.\AS2CM`0!,``!``\\!`!SO`<TH[0$`3```0`//`0`<[^',*.T!`$P``$`#
MSP$`'._!S"CM`0!,``!``\\!`!SOH<PH[0$`3```0`//`0`<[X',*.T!`$P`
M`$`#SP$`'.]AS"CM`0!,``!``\\!`!SO0<PH[0$`3```0`//`0`<[R',*.T!
M`$P``$`#SP$`'.\!S"CM`0!,``!``\\!`!SOX<LH[0$`3```0`//`0`<[\'+
M*.T!`$P``$`#SP$`'.^ARRCM`0!,``!``V.`_@)A8,$I>"#!*7=`P2EY`,$I
M>N#`*?@!`!H8H_XH#`,`)HT`%0!E0,`I9B#`*65`P`)F(,`"9'#``FR@P"EM
M<(`I_U__5^8!`!K&P/XHY`$`&H2`_RC%`!4``'P]5.P!`!J,X?\HC`$`*H`1
M`4!7&0<8[`$`&HQ!_RB-"0PX>1P`)*Q)$BHD$X`"A`Q!`(P-@`.L21(I_WO^
M5VY`P"CL`0`:D0'!*,\!`"9P'``DTP<"&/('`ACD(L`I#02``I,@P"F28,`I
MD4#`*8\``"<Y#X`"AP`5``P0@`*P*0!DSB'``A`.@`+/`0`FC0$5`*T-00",
M!8`"[S0<.,XAP`*0Z?]?Y&+`*(P-00`(`!4`X#`<."8#%0!%30`8_Z?[5X"(
M`$#D8L`H>I#``O]W_5>9`!4`10,5`$3M`1@`1`)4@'0`0.1BP"C_2_M7_V?\
M5VV@P"@,`P`FK(D`7&%@P2AW0,$H>"#!*'K@P"@D`Q4`>0#!*&.`P0(@``!,
M_]?[5]<0!QCD8L`I@%P`0/]G_%?L`0`:C4'_**T)##BM_=\"H#T$*?_7_E/D
M8L`H_V?[5_]W_U/D0L`H@`P`0`!\'U3_A_]310,5``3E`1@`M`%4Y$+`*9]P
M_T,`8!]4_VO_4__3_5<$!(`"_UO[5P``0`.)`!4`)```&@P`\P+L__\7C/T_
M`X2P$`!E`,`H9B#``@,`@P`'`!4`"``5`&H`%0`A```:#`#K`NS__Q>,_3\#
M(;`0`"$``$PA```:#,#O`NS__Q>,_3\#(;`0`"$``$P``$`#``!``P``0`,`
M`$`#8\#_`G8@P"EV0,`"Y`@'&,P(!QB$+0!8[`$`&HP!_RB`(0!`=B#`*&-`
MP`*``0!,``!``P``0`,``$`#``!``W8@P"AC0,`"(```3```0`/$!@<8I08'
M&*60$0!CP/\"K`Q)`*7\10!V(,`II;`0`'9`P`*E!$D`H"@`0.P!`!J,(?\H
M@!T`0'8@P"AC0,`"@`$`3```0`,``$`#``!``W8@P"AC0,`"(```3```0`-C
M@/\"=D#`*7<@P"EA8,`I=H#``G<#!QCL`@`J@"D`1.P!`!J,P?\H@!$`0.P!
M`!J$(<$H_[_[5_\;_U<,!(`"[`(`*6%@P"AV0,`H=R#`*&.`P`(@``!,8\#_
M`G8@P"EV0,`"=B#`*&-`P`+_-_]38P#_`G?`P"EAX,`I?0``)\P!`!J,X?XH
MG0$`)A<`%0"@EP!`>8#`*7I@P"E[0,`IC```*)H`%0"[`!4`F0`5``WT@`*`
MM0!`C1$`6"P'`"@Y!\`"G_7_1SEK$0"W`P`FX*(`0'B@P"E\(,`IN`,5`!ST
M@`(``$`#)@,5`$4#%0#D`A4`_Z_Z5X`,`$3L9B`XG%$`6!<CP"@8(\`"_][_
M1WB@P"AY@,`H>F#`*'M`P"A\(,`H8>#`*'T``";D`A4`=\#`*&,`P0(@``!,
M``!``P``0`,``$`#``!``P``0`,8]Q$`.0?``A@/20#WYA``>`,`)?^O_U,9
M`!4`_V/_4WF`P"AZ8,`H>T#`*/^K_U-C0/T"=X#"*7A@PBEAH,(IV`$`&ABC
M_B@,`P`F92#``I<`%0!L(,(I_[OZ5X!$`$1N&``D[`$`%(T``!2,N10`C0T`
M6$T!`!2-+0!<!0B``N0"%0#_[_E7A`1``@`8`%```$`#``!``P``0`,``$`#
M!``5`&T@PB@,`P`FK!D`7&&@PBAW@,(H>&#"*&/`P@(@``!,_X_Z5V,`_0)Y
M@,(I8>#"*=D!`!HYH_XH+`,`)FP@PBF`&`!`=\#"*8P``"J7`!4`@"T`1'?`
MPBAM(,(H+`,`)JQI`5QAX,(H>8#"*&,`PP(@``!,``!``P``0`-XH,(I___W
M5Y@`%0"`5`%`>F#"*00#%0#_"_A7@,P`0(Q,`"J:3,`"C$F_`HV!0`"`"0!$
M30<`*K_=_T.,3``JC$F_`HV!0`"`%0!$3`<`*HQ)OP*-@4``@,D`0+^Y_T/D
M`A4`>T#"*?^[]E>;`!4`1`,5`/^O]E=D$Q``A`B``O]#^%=)`Q4`Z`(5`&>_
M`1@&_+\"!02``IH`%0#_I_E792#``D0#%0#_6_A7#/R_`HP8`%AN&``D[`$`
M%(T``!2,N10`C7T`6$0#%0#_A_=71`,5`/^_]U<$`Q4`>T#"*/]#]U>?//]'
M!`,5`/^W^%?D`A4`_V_V5W?`PBAXH,(H>F#"*/_;_E,``$`#``!``P``0`,`
M`$`#``!``P``0`--"P`J_SO_4P``0`,``$`#``!``P``0`,``$`#``!``T0#
M%0#_9_Y7_XO_4W?`PBEXH,(I>F#"*7M`PBG_U_A7=\#"*'B@PBC_=_Y3``!`
M`V.`_@)W0,$I>"#!*7D`P2E[P,`I86#!*7K@P"E\H,`I?8#`*:P``"K8`0`:
M&*/^*`T#`":,]<`#C`5``KFP$`"7`!4`)`,5`&T@P"G_9_57FP`5`&40P`+D
M`A4`_S?\5X!0`4":`!4`_TOU5YL$`6Q\!``DW0$`&KWC_BB<#T$`[0(`*.P"
M%0`.](`"H.4!0*X1`%B-!0`HC`7``K_U_T>,71$`N@,`)F0+P`*$L!``_Z/V
M5T1S'#B`>`!`K0,`)NP"`"CD!L`"KG$,.`_T@`+,`0`I@"T`1`"X`%```$`#
M``!``P``0`,``$`#``!``XP``"B$!,`"K`4`*8"5`$#-`14`S@7``H_I_U\/
M](`"K@7``@P`%0"O`0`I``!``RTS`#C-,1`XC`7``K_U_T=M(,`H#`,`)JQ-
M`5QA8,$H=T#!*'@@P2AY`,$H>N#`*'O`P"A\H,`H?8#`*&.`P0(@``!,``!`
M`P``0`,``$`##``5````0`,M,P`X33,0.(P%P`*_]?]'_ZO_4P``0`/-`14`
M_WO_4P``0`,``$`#``!``P``0`,``$`#``!``WY@P"E_0,`IW0$`&KWC_BB_
M`P`F[`,`)H"Q`$#L`Q4`&@`5````0`.-(<`H3@,5`(PAP`):!X`"O_'_1\X-
M@`+$#4$`K-4&&(T!`"2@50!$#02``HT!`"7_2_57G@`5`("``$!<#T$`Y0,5
M`(8#%0#_4_57O@,`)TP'@`*,#4$`P#,<.'Y@P"A_0,`H>A"`*?]#_E,``$`#
M``!``P``0`.%`!4`Y`,5`/\+]E>D`P`GG@`5`(`L`$!<#T$`_[__4PP`%0#_
M,_Y3!$"``AH`%0#_=_]3?F#`*7]`P"G_-_97?F#`*']`P"C_F_Y3``!``V,`
M_P)WP,`I>*#`*7F`P"EZ8,`I8>#`*=@!`!H8H_XH#`,`)NW__Q5CM!``F@`5
M`+D`%0`&_+\#92#``J2A`1AL"!`G_[_S5Y>`0``7:`!D[?Z_`FRT$`",(0`J
M@%4`0'L0$"=[(,`"Y@(5``6\@`)D`Q4`___R5X"8`$#,`0`:C$'_*(0)##AF
M`Q4`YP(5`$4#%0#_#_17>Q`0)@`P`%```$`#``!``P``0`,``$`#H'$`1,P!
M`!J,0?\HA`D,."8#%0!%`Q4`_]OR5VT($"8,`P`FK$4`7"T``!1CM!``8>#`
M*'?`P"AXH,`H>8#`*'I@P"AC`,$"(```3```0`,``$`#``!``P``0`,``$`#
M>Q`0)O^C_U-[$!`G_P?U5WL0$">W`14`_S__4P``0`-CP/\"=P``)V$@P"G7
M`0`:[$+_*(0)##B'HP,8Q@$`&L9@_RAEF0$8_ZOT5_="_RCD"@PX82#`*'<`
M`"8HM0$8"0`5`.:>`!@'`14`)9D!&&-`P`+_S_)3S`$`&HQ!_RB$"0PX)Z$#
M&,8!`!K&8/\H!9<!&/]?]%-CP/X"82#!*7<`P2EXX,`I><#`*7J@P"G:`0`:
M6J/^*$P#`";-__\58[00`&P8("?_"_-7=R#``B8``!2(`!4`B98!&*>6`1C&
M!(`#!02``N0"%0#_-_17+```%(Q!@`-YL!``Y`(5`"8``!0E`Q4`_^OQ5Y>`
M0``8`!4`X"8`8.0&@`+_A_)7F``5`(`4`$#F`A4`)0,5`/^S\U<`7Q`X;1@@
M)DP#`":L+0!<30``%&.T$`!A(,$H!`,5`'<`P2AXX,`H><#`*'J@P"AC0,$"
M(```3/^G\U?_*_]3``!``V.`_`)W0,,I>"##*7D`PRE[P,(I86##*>W__Q7;
M`0`:>Z/^*&.T$`!M`P`FF0`5`+<`%0#DD`$891#``FV($"?_*_=7F``5``6\
M@`(D`Q4`_QOP5X!4`$!$D`$8)0,5`/][^E<D`Q4`;8@0)FP#`":LX0%<+0``
M%&.T$`!A8,,H=T##*'@@PRAY`,,H>\#"*&.`PP(@``!,``!``P``0`,``$`#
M``!``^0"%0!ZN!`G?*@0)WZ8$"?_\_!7I8T!&/\;\U>7`!4`'/R_`WH@P@)^
M(,`"@&P!0'V@$"<``$`#[`(`*H#E`$``%P!`Y0(5``0#%0#_Y^]7@*@`0.0"
M%0#_B^]7C/S_`NRR$`"=`!4`#KR``NPB`&@`,`!0``!``P``0`,``$`#@`$`
M*8S]_P+L#@!8C0$`*J[Q_UOD`A4`_TOO5YT`%0`D`Q4`_S_O5X3T$`"$!,`"
MA%\`:`4$@`(J`Q4`J8@!&.@"%0"GB`$8)@``%$0#%0#_,_)7Q0,5`$0#%0#_
MY_!7@!@`1&X8`"3L`0`4#0$`%(RY%`"-;0!8A88!&`0`%0#_,_)7EP`5`)\P
M_T=ZN!`F?*@0)GV@$"9^F!`F_Y?^4P`?`$`,`P`JC$F_`HV!0`"`"0!$#0<`
M*K_!_T,=!(`"%X,!&/]?_U,``$`#``!``P``0`,``$`#``!``P``0`,%!(`"
M1`,5`/^K\%>?C/]'10,5`"2"`1C_N_A71`,5`/^#[U=ZN!`F?*@0)GV@$"9^
MF!`F_R_^4WJX$"9\J!`F?I@0)O\/_E-ZN!`G?*@0)WV@$"=^F!`G_SOQ5P``
M0`-CP/\"!;R``G<``"=A(,`IEP`5`/\_[E>,!,`"]Y(3`(01$P!A(,`HA%P5
M`'<``"9C0,`"_P_O4V-`_P)Y0,`I8:#`*=D!`!HYH_XH+`,`)NW__Q5CM!``
M;`@0)X#(`$!X&!`GC```*I@`%0"`M0!`=R`0)_^O[5<L```4A@3``I<`%0"&
M_0!H;2#``@4#%0"D`14`_V_P5^S^_P*,L!``#KR``HPH`&@`+`!0``!``P``
M0`,``$`#``!``P``0`.``0`IC/W_`H0-`%B-`0`JKO'_6W<@P`(%O(`"Y`(5
M`/]S[5>`O`!`Y'H`:&0@P`+_4^Y7;0@0)BP#`":LP0!<+0``%'<@$"9X&!`F
M8[00`&&@P"AY0,`H8\#``B```$QX&!`F;0@0)BP#`":D=0$8K)$`7"T``!1C
MM!``8:#`*'E`P"ACP,`"__OM4P``0`,``$`#``!``P``0`,``$`#@```*?^+
M_U,``$`#``!``P``0`,``$`#``!``P``0`,$`!4`_W/_4P``0`,``$`#``!`
M`P``0`,``$`#``!``VT($"8L`P`FK!4`7'<@$"9X&!`F9'$!&/]__U/_=^]7
M=R`0)W@8$"?_:^]7``!``V-`_P)W@,`I>&#`*7E`P"EAH,`IV`$`&ABC_B@,
M`P`F=Q#``MD!`!HYX_XH;"#`*>4"%0#D<`$8__OR5X!$`$!M!``D+P,`)JT-
M00#LM1``CB'`*.XU'#C?V?]#``!``XU!P"B,(<`"C0$`)[_U_T?E`A4`Y&X!
M&/^[\E>?Q/]'V0$`&CGC_BCE`A4`I&X!&/^C\E>`1`!`;00`)"\#`":M#4$`
M[+40`(XAP"CN-1PXW]G_0P``0`.-0<`HC"'``HT!`">_]?]'Y0(5`*1L`1C_
M8_)7G\3_1]D!`!HYX_XHY0(5`"1L`1C_2_)7@$0`0&T$`"0O`P`FK0U!`.RU
M$`".(<`H[C4<.-_9_T,``$`#C4'`*(PAP`*-`0`GO_7_1^4"%0`D:@$8_POR
M5Y_$_T?9`0`:.>/^*.4"%0#D:0$8__/Q5X!$`$!M!``D+P,`)JT-00#LM1``
MCB'`*.XU'#C?V?]#``!``XU!P"B,(<`"C0$`)[_U_T?E`A4`Y&<!&/^S\5>?
MQ/]'V0$`&CGC_BCE`A4`9&<!&/^;\5>`1`!`;00`)"\#`":M#4$`[+40`(XA
MP"CN-1PXW]G_0P``0`.-0<`HC"'``HT!`">_]?]'Y0(5`&1E`1C_6_%7G\3_
M1]D!`!HYX_XHY0(5`"1E`1C_0_%7@$0`0&T$`"0O`P`FK0U!`.RU$`".(<`H
M[C4<.-_9_T,``$`#C4'`*(PAP`*-`0`GO_7_1^4"%0`D8P$8_P/Q5Y_$_T?9
M`0`:.>/^*.4"%0"D7@$8_^OP5X!$`$!M!``D+P,`)JT-00#LM1``CB'`*.XU
M'#C?V?]#``!``XU!P"B,(<`"C0$`)[_U_T?E`A4`I%P!&/^K\%>?Q/]'V0$`
M&CGC_BCE`A4`)&`!&/^3\%>`1`!`;00`)"\#`":M#4$`[+40`(XAP"CN-1PX
MW]G_0P``0`.-0<`HC"'``HT!`">_]?]'Y0(5`"1>`1C_4_!7G\3_1]D!`!HY
MX_XHY0(5`.1=`1C_._!7@$0`0&T$`"0O`P`FK0U!`.RU$`".(<`H[C4<.-_9
M_T,``$`#C4'`*(PAP`*-`0`GO_7_1^4"%0#D6P$8__OO5Y_$_T>Y`0`:.>/^
M*.4"%0"D6P$8_^/O5X!$`$!M!``D+P,`)JT-00#LM1``CB'`*.XU'#C?V?]#
M``!``XU!P"B,(<`"C0$`)[_U_T?E`A4`I%D!&/^C[U>?Q/]'N0$`&CGC_BCE
M`A4`)%0!&/^+[U>`1`!`;00`)"\#`":M#4$`[+40`(XAP"CN-1PXW]G_0P``
M0`.-0<`HC"'``HT!`">_]?]'Y0(5`"12`1C_2^]7G\3_1^4"%0#D5@$8_SOO
M5X4`%0"`#`!`9%4!&/^;\E?E`A4`Q%8!&/\?[U>%`!4`@`P`0`17`1C_?_)7
MY0(5`"17`1C_`^]7A0`5`(`X`$#D3@$8_V/R5VT@P"@,`P`FK$4`7&&@P"AW
M@,`H>&#`*'E`P"C%5@$8Y%`!&&/`P`+_-_)3Y0(5`&15`1C_N^Y7A0`5`)_$
M_T/D4`$8_QOR5_^[_U/_T^I7``!``V.`_P)W0,`I86#`*;<!`!KWHOXH[`(`
M)F40P`)D3P$8;"#`*?]W[E>,`!4`!``5`(`5`$"$`0`HC$#_`@RP$@"$$1,`
M;2#`*.P"`":L%0!<86#`*'=`P"AC@,`"(```3/]KZE<``$`#8X#^`F%@P"FO
M`0`:[Z'_**T!`!JMH?XHK0$`)HX`%0#D`0`F;*#``F6@P"EFP,`I9^#`*<8!
M%0"'`14`!02``F@`P2EI(,$I:D#!*6M@P2EM(,`I;```)_^[YU<$_(,"_Y/G
M5P``0`-C@/X"=T#!*7@@P2EY`,$I>N#`*7O`P"E\H,`I?8#`*7Y@P"EA8,$I
M#?[_%;H!`!I:H_XH8[00`$P#`"9M!``0K2'``@8(@`(%`!4`K`$`)Y@`%0#_
MU^E7E_S_`NW^20"MP44`[+80`(P!SP",M1$`][(1`!G\OP(;'(`"?0`5`%YH
M!A@<_O\5X.H`8```0`,&`!4`Y0(5``0#%0#_C^E7F>``6`8"`!2E`Q4`!`,5
M`,8@@`/_U^A7A(!``)F\`%ADJP!LC.#_`JRS$`"=)0!L`)@`4```0`,``$`#
M``!``P``0`,``$`#C/W_`IU]`&C.`P`FC0$`)LWQ_U^,]1$`A-T0`&P$`!",
M(<`"C0$`)DP#`":L=0!<#0(`%&.T$`!A8,$H=T#!*'@@P2AY`,$H>N#`*'O`
MP"A\H,`H?8#`*'Y@P"AC@,$"(```3```0`,``$`#``!``P``0`,``$`#``!`
M`P``0`/W_O\3_";_7P3\OP+_D_]3A$,!&/\?_E?$0@$8_Q?^5_]SZ%<``$`#
M8\#_`F$@P"G_D^=7___F5X`(`$"$```F82#`*&-`P`(@``!,``!``V,`_P)X
MH,`I>8#`*6'@P"FY`0`:.:/^*"P#`":8`!4`91#``N1``1AL(,`I_^?K5X`8
M`$!WP,`IC```*I<`%0"`,0!$=\#`*&T@P"@L`P`F!0,5`&0_`1BLC0!<8>#`
M*'B@P"AY@,`H8P#!`O\7[U,$`Q4`>F#`*?^[Y%>:`!4`Y`(5`/^OY%=$DQ``
MA`C``O]#YE?J`A4`"30!&`@#%0!'-`$8!OR_`@4$@`*7`!4`_Z/G5VT@P"@L
M`P`FK#4`7'I@P"AAX,`H>*#`*'F`P"CE`A4`=\#`*$0[`1AC`,$"_Z/N4W?`
MP"EZ8,`I_U?G5_]3YU<``$`#8X#Y`G@@QBEY`,8I>N#%*4Q6!AAA8,8I@$$`
M+&"`02QW0,8I@($`+&#`02RZ`0`:6J/^*(#!`"Q@`$(L3@,`)GAPP`*9`!4`
MT3@!&'`M`1C/.`$8[3@!&`4#%0`D+0$8<8#`*7"@P"E@P,`I;P#!*6X@Q2EM
M(,$I8$#!*?^?ZE>`$`!`C```*I<`%0"`#0-$>\#%*7R@Q2E]@,4I_]_E5_]+
MY5>`%`)`EP``)N`.`D#D`A4`_X?C5X0$00"$!,`"_QOE5^@"`"B<`!4`FP`5
M```Q`$```$`#"(%G`(0#%0`'-0$8!OR_`@4$@`+_;^97Z`8`*)P+P`+W!L`"
M']W_1WR`P0(D+P$8`!P`4```0`,``$`#``!``X0CP"B<(\`"@#@`0`4#%0#_
M\^E7EP`5`)_H_T.,```JG^'_0__OZE>?V/]#Y`(5`/\3Y%>7`!4`@#0`1```
M0`-\@,`"EP,`)N`F`$#L`@`J@#$!0.0"%0#_N^I7@`0!1)<CP"B<(\`"_^;_
M1^0"%0#_L^)7G0`5`&0#%0#_I^)7O1,0`+T3D`*D`Q4`_S?D5VL#%0#J+@$8
MR2,!&.@"%0#'+@$8!OR_`@4$@`*<`!4`_Y/E5P4`AP*$`Q4`_Y?E5PS\OP*,
M%`!<_TOD5XD``"0,1(`"+'4!7&5`P@*$`Q4`_Q/E5Y<`%0"`&`!$;J``).P!
M`!2-```4C+D4`(TE`5BL`0`:C*'_*"<#`":$`0`FB`,5`*8M`1@%!(`"_]?B
M5QL`%0```$`#;2#%*$P#`":L%01<86#&*'R@Q2A]@,4H=T#&*'@@QBAY`,8H
M>N#%*&0#%0![P,4H8X#&`B```$SD`A4`_]_B5Y<`%0"<(\`"G]3^0__[_E,`
M`$`#``!``Q<`%0#_Z_Y3``!``P``0`,``$`#``!``P``0`,``$`#>P#!`@``
M0`-D`P`F@"0`0`4#%0#_3^A7@`P`0(P``"J`00!$9"/`*'LCP`*?Y/]'!#2`
M`O_OXE><`!4`-R,!&`A,@0*;`!4`_]O]4P``0`,``$`#``!``P``0`,``$`#
M_T/B5Y<`%0![(\`"GYS_0_\3X5>$!$$`A`3``O^/_5-[J``D_S_C5V3;_E]L
MH``D?F#%*0T`AP*,_4<#C74`6'Y@Q2C_O_Y3K`$`&HRA_R@G`P`FA`$`)H@#
M%0!F(0$8!02``O^/X5?_N_Y3``!``P``0`,``$`#``!``P``0`/_<_M7;2#%
M*$P#`":LP0)<86#&*'@@QBAY`,8H>N#%*.0"%0!W0,8H8X#&`O^7X5.D`Q4`
M_P_B5P4#%0";`!4`!",!&/\_YU>%`!4`@%0!0"0#`";_Q^]7G@`5`(!$`4#$
M`Q4`_S_@5YV`0``,#(`"G3$`9*3S_P*%(0$8Q),0`/]SX%>`'`!$#!"``JS[
M`5B][[\"S7<@.`R\@`*LZ0%8!0,5`&02`1C_V^97@!0!0(P``"B`#0%`#<"`
M`HT%`5A%%@$89!$!&/\KZE?_I^%7B@`5`&LF`1C)#0$8B`,5`,<?`1@&_+\"
M!02``F0#%0#_T^)7&/R_`AE$@`(])0$8`%P`4```0`,``$`#``!``P``0`,`
M`$`#``!``P``0`/_<^%7C```))E%`%S_1^%7]P:``HH`%0!]```GJ0H!&.L"
M%0"(`Q4`!QT!&`;\OP(%!(`"9`,5`/]KXE<%`(<"9`,5`/]OXE>8N/];A`,5
M`/^CX%=E`Q4`A`<!&/]WZ5=D`Q4`_^_Y5WY@Q2C_'_U3``!``P``0`,``$`#
M``!``SX#`";_O_Y3``!``P``0`,``$`#``!``P``0`,``$`#!0`5`,0#%0#_
M6^!7F``5`)_P_D/_Y_=7F0`5`(#D_F.%V/\"!@`5``0#%0#_]^%7?4#$`@88
M@`($`Q4`I0,5`/]#X5<,&(`"C+0`7&T0`22,@H84C`&,`ZRI_E^M$T`JC```
M%(PAE0.LF?Y?!@`5`"4[_P($`Q4`_ZOA5W=@Q`(&H(`"!`,5`.4"%0#_]^!7
M#*"``HQH`%Q+&@$8Z@(5`(D!`1B(`Q4`!Q,!&`;\OP(%!(`"9`,5`&``!2G_
M1^%7_^_^4SDCP"@_&_Y#)`,5`/\3WE<,#(`"A`G^;X3P_P*%$`$8)),0`/]+
MWE?>$Q,`)),3`-X3%0#_Z_U3Y`\!&/^3]E=^8,4I_^O@5WO`Q2E\H,4I?8#%
M*7Y@Q2G_U^!78P#_`G?`P"EY@,`I>F#`*6'@P"EXH,`I>T#`*;D!`!HYH_XH
M+`,`)K<!`!IZ$,`";"#`*>Q"_RB8"0PXI/T`&$4#%0`,PP(J#,<"*?]7Y%>`
M$`!`C0``*@S$@`*LI0%8_Q/Q5^Q"_RB8"0PX!`,5``<,@`(&!(`"10T!&/_'
MW5>8`!4`@#``0(Q`P"CM0O\HI`D,.(4!`":&#`$8_[?=5PQ#P"B%`0`FK`P`
M)(Q9U@"`D0%$[$+_*(0)##@'#(`"!@2``F4+`1C_>]U7F``5`%L?!AB`+`!`
M10,5`.3U`!C_P^-7#$/`*(8`%0"%`0`F@#`!0.Q"_RB$"0PX_U?=5^Q"_RB8
M"0PX!@2``F4)`1@$`Q4`_[_<5X4`%0"F"0$8!`,5`/\OW5?W0O\H[`H,.$4#
M%0"D\@`8@,4"*?]GXU=D0\`IEP`5`("8`$`%`(<"Y`(5`/^?WU<,!(`"C02`
M`HU!`&P,1(`"C#@`6&PCP"B'`!4`Y@(5`(4!`"8D"`$8_Y/>5P``0`,``$`#
M``!``P``0`,``$`#``!``P``0`-M(,`H+`,`)JRI`%QAX,`H=\#`*'B@P"AY
M@,`H>F#`*'M`P"AC`,$"(```3```0`,``$`#``!``P``0`,``$`#9"/`*/^G
M]U=D0\`IEP`5`)]<_T<D`P$8_QO>5P``0`.,!``JGVG^0_];_E,``$`#``!`
M`P``0`,``$`#``!``VPCP"BD`!4`A0$`)O^'Z%?_T_Y3``!``P``0`,``$`#
M[$+_*(0)##C_F]U7_VO^4_^#WE<``$`#8T#_`G>`P"EX8,`I8:#`*;<!`!KW
MHOXH[`(`)I@`%0!E$,`"I.P`&&P@P"G_'^)7@"``0(P``"B`&0!`#<"``HT1
M`%@`#P!`#`,`*H`]`$1M(,`H[`(`)JRY`%QAH,`H=X#`*'A@P"ACP,`"(```
M3```0`,``$`#``!``P``0`,``$`#``!``P0#%0!Y0,`I__/L5P6\@`*9`!4`
M___:5XP$P`(YDQ,`A!$3`(1D%0#_V]M7!A"``@7P`!C_O]Q7@"@`0'E`P"C_
MB_]3``!``P``0`,``$`#``!``P``0`,``$`#``!``VT@P"CL`@`FK"4`7'E`
MP"AAH,`H=X#`*`0#%0!X8,`H8\#``O_GXE-Y0,`I_V?=5P``0`,``$`#``!`
M`P``0`.T`0`:E*+^*(P"`"9C@/4"YP$`%&%@RBEW0,HI<0`5`.<`O`-R`!4`
M!OX!%)#@P`*%X,$";"#**0\"`"8-`@`D4D+``NZ!10#LH44`TV%!`._A10",
MG10`C#T5`*TQ``#.(4$`;P+?`*W!3`#.F10`C#T5`*T!WP",.14`$"+``DW"
M_RE,XO\I!;+_7VR@P0)@0``L9X``+&;``"PMHLD"8P`!+&5``2QD@`$L8<`!
M+&(`)W&)83XL@`$`+"@`U'.,0<`"`"0G<0`()W$!?#%SCN$"&``$+7,A@"9Q
MP`$`+"$`)G&!(4`LX`#4<\<`U'-F`-1SHP#4<X4`U',$`=1SC;'_7Y(``"9N
M```FDX#`*.4$M12E9*8#D4#`*(\@P"B08,`H26Y%`$P600",)14`SI40`,[-
M$`",`=\`+<(5`.D)10",N1``[GE!`&@@P"BMO10`SB45`,D!WP"MP14`C+40
M`"VF%0`(E1``K<D4`(P!WP`(P1``K<45`(IM10"MH1``B!5!``@I%0!G0,`H
M2@I%`*VA$`!(>D$`""D5`&9@P"C.H14`YY00`,ZQ%`"M`=\`Y\00`,:4$`#.
MI14`QJ00`,Z=$`"I%4$`IVU%`"D=%0"'>4$`C`E%`.<P%0#,I1``#IT5``D!
MWP#.M10`C`'?`,ZE%0#.F1``B&U%`(8500#&(!4`J'E!`*T)10`(-14`S9D0
M`&Z`P"BF`=\`[:`5`.L`WP#.E1``K;$4`,ZE$`"MK14`RA1!`*VY$`#.;$4`
M3CD5`(=Y00","44`YS`5`*RY$`!MH,`HC@'?``R=%0"ME1``"`'?`(R9%`"M
MK1``C*$5`,D500",M1``S6U%`"DU%0",I1``RGA!`,T(10!&-14`C0'?`&S`
MP"CJ`-\`J15!`(R5$`"(H1``[)@5`(RY%`"G;44`C*D5`(RA$``H'14`C*$0
M`&C@P"C'>4$`S@E%`.<X%0`(E1``C@'?`,R<%0`(J1``C+44`,H`WP#)%4$`
MQFU%`(RI%0",H1``*!D5`(RA$`!H`,$HIGE!`*T)10#&-!4`")40`(T!WP#L
MF!4`"*D0`(RY%`#J`-\`J15!`*=M10",J14`C*$0`"@=%0",H1``:"#!*,=Y
M00#."44`YS@5``B5$`".`=\`S)P5``BI$`",M10`R@#?`,D500#&;44`C*D5
M`(RA$``H&14`C*$0`&A`P2BF>4$`K0E%`,8T%0`(E1``C0'?`.R8%0`(J1``
MC+D4`.H`WP"I%4$`IVU%`(RI%0",H1``*!T5`(RA$`!H8,$HQWE!`,X)10#G
M.!4`")40`(X!WP#,G!4`"*D0`(RU%`#*`-\`R15!`,9M10",J14`C*$0`"@9
M%0",H1``:(#!**9Y00"M"44`QC05``B5$`"-`=\`[)@5``BI$`",N10`Z@#?
M`*D500"G;44`C*D5`(RA$``H'14`C*$0`&B@P2C'>4$`S@E%`.<X%0`(E1``
MC@'?`,R<%0`(J1``C+44`,H`WP#)%4$`QFU%`(RI%0",H1``*!D5`(RA$`!H
MP,$HIGE!`*T)10#&-!4`")40`(T!WP#LF!4`"*D0`(RY%`#J`-\`J15!`*=M
M10",J14`C*$0`"@=%0",H1``:.#!*,=Y00#."44`YS@5``B5$`".`=\`S)P5
M``BI$`",M10`R@#?`,D500#&;44`C*D5`(RA$``H&14`C*$0`*9Y00!H`,(H
MK0E%`,8T%0"-`=\`[)@5``B5$`#G`-\`C+D4``BI$`",G14`J15!`(RA$`"H
M;44`*"$5`(RA$`#)>4$`S@E%`"DY%0".`=\`;"#"*,H`WP#(%4$`C)40`(>=
M$`#,I!4`C+44`,9M10",J14`C)T0``<9%0",G1``J'E!`&=`PBBM"44`"#45
M`"VA%0#GE!``*0'?`*VY%`",`=\`YZ@0`*VE%0"MG1``AA5!`(=M10#&'!4`
MRWE!`,X)10!K.14`S@#?`*:Y$`!N8,(H#:T5`*VQ%``(`=\`Q940`,<`WP"E
MI!``K:$5`*V5$`#N%$$`Y6Q%`,X5%0"*>4$`C`E%`$HQ%0!E@,(HS`'?`*ZQ
M$`#-L]T4K86N`VRI%0",F14`I;00`,D!WP"EH!``C`'?`(R5$``F;44`)15!
M`*48%0"E`-\`A940`&R@PBBF`-\`Z'A!`&L!WP",M1``YPA%``<=%0",K1``
MR!1!`,ML10`(+14`2YT5`&ZY%0#.`=\`"`'?`(RY$`".H1``;,#"*$H!WP#(
M`=\`C+40`(RI$``J>4$`*0E%`$DE%0`+%4$`"FU%`&LI%0#JI!4`1945`*4`
MWP!K`=\`C)40`(6M$`!LX,(HZ@#?`*<`WP",M1``C*D0`,IX00#&"$4`2AD5
M`.ML10#F%$$`QBP5`"NI%0!NN14`S@'?`,8`WP",N1``CID0`&P`PR@I`=\`
MQ@'?`(RU$`",I1``"7E!``@)10`I(14`RVQ%`,@400`(+14`2Z45`&65%0"E
M`-\`"`'?`(R5$`"%H1``;"##*$H!WP"H`-\`C+40`(RI$`#J>$$`YPA%`$H=
M%0`+;44`!Q5!`.<L%0`KJ14`;KD5`,X!WP#G`-\`C+D0`(Z=$`!L0,,H*0'?
M`,<!WP",M1``C*40`,EX00#&"$4`*1D5`.ML10#F%$$`QBP5`$NE%0!EE14`
MI0#?`,8`WP",E1``A9D0`&Q@PRA*`=\`I@#?`(RU$`",J1``"GE!``@)10!*
M(14`RVQ%`,@400`(+14`*ZD5`&ZY%0#.`=\`"`'?`(RY$`".H1``;(##*"D!
MWP#(`=\`C+40`(RE$`#I>$$`YPA%`"D=%0`+;44`!Q5!`.<L%0!+I14`9945
M`*4`WP#G`-\`C)40`(6=$`!LH,,H2@'?`*<`WP",M1``C*D0`,IX00#&"$4`
M2AD5`.ML10#F%$$`QBP5`"NI%0!NN14`S@'?`,8`WP",N1``CID0`&S`PR@I
M`=\`Q@'?`(RU$`",I1``"7E!``@)10`I(14`RVQ%`,@400`(+14`2Z45`&65
M%0"E`-\`"`'?`(R5$`"%H1``;.##*$H!WP"H`-\`C+40`(RI$`#J>$$`YPA%
M`$H=%0`+;44`!Q5!`.<L%0`KJ14`;KD5`,X!WP#G`-\`C+D0`(Z=$`!L`,0H
M*0'?`,<!WP",M1``C*40`,EX00#&"$4`*1D5`.ML10#F%$$`QBP5`$NE%0!E
ME14`I0#?`,8`WP",E1``A9D0`&P@Q"A*`=\`I@#?`(RU$`",J1``"GE!``@)
M10!*(14`RVQ%`,@400`(+14`*ZD5`&ZY%0#.`=\`"`'?`(RY$`".H1``;$#$
M*"D!WP#(`=\`C+40`(RE$`#I>$$`YPA%`"D=%0`+;44`!Q5!`.<L%0!+I14`
M9945`*4`WP#G`-\`C)40`(6=$`!L8,0H2@'?`*<`WP",M1``C*D0`,IX00#&
M"$4`2AD5`.ML10#F%$$`QBP5`"NI%0!NN14`S@'?`,8`WP",N1``CID0`&R`
MQ"@I`=\`Q@'?`(RU$`",I1``"7E!``@)10`I(14`RVQ%`,@400`(+14`2Z45
M`&65%0"E`-\`"`'?`(R5$`"%H1``;*#$*$H!WP"H`-\`C+40`(RI$`#J>$$`
MYPA%`$<=%0`+;44`"A5!`$HM%0`KG14`;KD5`,X!WP!*`=\`C+D0`(ZI$`!L
MP,0H*0'?`,IX00",M1``C*40`&G@Q"C&"$4`2AD5`"FU$`#MJ!4`K945`,L!
MWP"M`=\`96U%`.<`WP",M1``;15!`"F=$`"M%14`!WE!``4)10#G%!4`19T5
M`*ZX%0#.`=\`C+40`"6Y$`!I`,4H;C<>%88!WP!M"44`;'E!`,YQLP,.```6
MC#45`,L400#-;$4`:S45`"FY$`!-`=\`B`'?`"FU$`#M,!4`I:P0`*V9%`#K
MH!0`K2T5`*VE$`!I(,4HI0#?`.<`WP`IN1``JA1!`"F=$`"G;$4`1QT5`*V=
M$`#'>$$`Q@A%`.<8%0",'14`I@'?`(R5%`#MH!0`C#45`(RE$`!I0,4HS11!
M`.H`WP`IN1``*:$0`,AL10"M(14`C+40`*UX00"E"$4`K145`*@!WP#E-!4`
MI9@4`.>@%`"E'!4`I:00`&E@Q2B,`=\`AQ5!`"FY$``IJ1``BFU%`.<H%0"E
MG!``QWA!`,8(10#G&!4`K1T5`*8`WP"ML10`Y:`4`*T5%0"MI1``:8#%*,44
M00#J`-\`*;D0`"FA$`#(;$4`I2`5`*V5$`"%>4$`C`E%`*PP%0"(`=\`Y3`5
M`*68%`#GH!0`I1P5`*6D$`!IH,4HK0'?`*<500`IN1``*:D0`*IM10#G*!4`
MI9P0`,=X00#&"$4`YQ@5`(P=%0"F`-\`C+44`.6@%`",%14`C*40`&G`Q2C%
M%$$`Z@#?`"FY$``IH1``R&Q%`*4@%0",E1``I7E!`*T)10"M-!4`J`'?`.4T
M%0"EF!0`YZ`4`*4<%0"EI!``:>#%*(P!WP"'%4$`*;D0`"FI$`"*;44`YR@5
M`*6<$`#'>$$`Q@A%`.<8%0"M'14`I@#?`*VQ%`#EH!0`K145`*VE$`!I`,8H
MQ11!`.H`WP`IN1``*:$0`,AL10"E(!4`K940`(5Y00","44`K#`5`(@!WP#E
M,!4`I9@4`.>@%`"E'!4`I:00`&D@QBBM`=\`IQ5!`"FY$``IJ1``JFU%`.<H
M%0"EG!``QWA!`,8(10#G&!4`C!T5`*8`WP",M10`Y:`4`(P5%0",I1``:4#&
M*,4400#J`-\`*;D0`"FA$`#(;$4`I2`5`(R5$`"E>4$`K0E%`*TT%0"H`=\`
MY305`*68%`#GH!0`I1P5`*6D$`!I8,8HC`'?`(<500`IN1``*:D0`(IM10#G
M*!4`I9P0`,=X00#&"$4`YQ@5`*T=%0"F`-\`K;$4`.6@%`"M%14`K:40`&F`
MQBC%%$$`Z@#?`"FY$``IH1``R&Q%`*4@%0"ME1``A7E!`(P)10"L,!4`B`'?
M`.4P%0"EF!0`YZ`4`*4<%0"EI!``::#&**T!WP"G%4$`*;D0`"FI$`"J;44`
MYR@5`*6<$`#'>$$`Q@A%`.<8%0",'14`I@#?`(RU%`#EH!0`C!45`(RE$`!I
MP,8HQ11!`.H`WP`IN1``*:$0`,AL10"E(!4`C)40`*5Y00"M"44`K305`*@!
MWP#E-!4`I9@4`.>@%`"E'!4`I:00`&G@QBB,`=\`AQ5!`"FY$``IJ1``BFU%
M`.<H%0"EG!``QWA!`,8(10#G&!4`K1T5`*8`WP"ML10`Y:`4`*T5%0"MI1``
M:0#'*,4400#J`-\`*;D0`"FA$`#(;$4`I2`5`*V5$`"%>4$`C`E%`*PP%0"(
M`=\`Y3`5`*68%`#GH!0`I1P5`*6D$`!I(,<HK0'?`*<500`IN1``*:D0`*IM
M10#G*!4`I9P0`,=X00#&"$4`YQ@5`(P=%0#FH!0`C+44`*4`WP",&14`C*40
M`*8400"I;$4`QB05`(R9$`"F>4$`K0E%`,TT%0!F0,<HJ0'?`.H`WP#&N!``
MR*`0`.8T%0#&E!0`YZ04`(P!WP#&'!4`QJ`0`(<500"(;44`YR`5`&A@QRBK
M>$$`YP#?``ZY$`#*J1``K@A%`&4Y%0#&G!``K145`,<`WP"NI!0`K;$4`.@4
M00"M.14`[FQ%``XY%0"+>4$`C`E%`&LQ%0"MJ1``S`'?`*ZQ$`!J@,<HC<64
M%:U9AP,-```6K*P5`(R9%0!&M1``R`'?`,:D$`",`=\`C)D0``EM10`&%4$`
MQB05`'>@QRC&`-\`AID0`,D`WP"E`-\`][80`.IX00#G"$4`2AT5`"QM10#W
MEA``)15!`*4P%0!LJ14`C+D5`(P!WP",W1``I0#?`(65$`!LP,<HIP#?``YY
M00!K`=\`C+40``@)10#((14`C*T0`.X400#K;$4`SBT5`$NA%0!FF14`Q@#?
M`(R9$`#.`=\`CKD0`&S@QRA*`=\`Q@'?`(RU$`",J1``*GE!`"D)10!*)14`
MRQ1!`,EL10!K)14`":D5`"65%0"E`-\`:P'?`(R5$`"%K1``;`#(*`D!WP"H
M`-\`C+40`(RE$`#I>$$`YPA%`"D=%0`+;44`!Q5!`.<L%0!+I14`;KD5`,X!
MWP#G`-\`C+D0`(Z=$`!L(,@H2@'?`,<!WP",M1``C*D0`,IX00#&"$4`1AD5
M`.L400#J;$4`:RD5`"J9%0!%E14`I0#?`&L!WP",E1``A:T0`&Q`R"@J`=\`
MJ0#?`(RU$`",J1``"GE!``@)10!((14`*Q5!`"IM10!K*14`RJ`5`$ZY%0#.
M`=\`:P'?`(RY$`".K1``;&#(*,H`WP#&`=\`C+40`(RI$`#J>$$`YPA%`$<=
M%0#+%$$`RFQ%`&LI%0`*G14`1945`*4`WP!K`=\`C)40`(6M$`!L@,@H"@'?
M`*@`WP",M1``C*D0`"IY00`I"44`2245``L500`*;44`:RD5`.JD%0!.N14`
MS@'?`&L!WP",N1``CJT0`&R@R"CJ`-\`QP'?`(RU$`",J1``RGA!`,8(10!&
M&14`ZQ1!`.IL10!K*14`*ID5`$65%0"E`-\`:P'?`(R5$`"%K1``;,#(*"H!
MWP"I`-\`C+40`(RI$``*>4$`"`E%`$@A%0`K%4$`*FU%`&LI%0#*H!4`3KD5
M`,X!WP!K`=\`C+D0`(ZM$`!LX,@HR@#?`,8!WP",M1``C*D0`.IX00#G"$4`
M1QT5`,L400#*;$4`:RD5``J=%0!%E14`I0#?`&L!WP",E1``A:T0`&P`R2@*
M`=\`J`#?`(RU$`",J1``*GE!`"D)10!))14`"Q5!``IM10!K*14`ZJ05`$ZY
M%0#.`=\`:P'?`(RY$`".K1``;"#)*.H`WP#'`=\`C+40`(RI$`#*>$$`Q@A%
M`$89%0#K%$$`ZFQ%`&LI%0`JF14`1945`*4`WP!K`=\`C)40`(6M$`!L0,DH
M*@'?`*D`WP",M1``C*D0``IY00`("44`2B$5`"L500`H;44`:R$5`,BH%0`.
MN14`S@'?`&L!WP",N1``CJT0`&Q@R2C(`-\`Q@'?`(RU$`",H1``Z'A!`.<(
M10`('14`RQ1!`,=L10!K'14`1Z$5`.64%0"E`-\`:P'?`(R5$`"%K1``;(#)
M*$<!WP"J`-\`C+40`(R=$``G>4$`*0E%`.<D%0!+%4$`26U%`&LE%0`)G14`
M+KD5`,X!WP!K`=\`C+D0`(ZM$`!LH,DH"0'?`,@!WP",M1``C*40`,EX00#&
M"$4`*1D5``MM10`&%4$`QBP5`.ND%0!KE14`Y0#?`&<!WP#&`-\`C)T0`(>9
M$`!LP,DH1GE!`$H)10#&*!4`C+40`(R5$``EF14`KK@5`,X!WP",N1``;N#)
M*.L`WP`I`=\`S;40`*W)$`"EI1``;FU%`&T)10!J%4$`<GE!`%(V%0!-.14`
M#GE!``@)10#.(14`C+40`,VX%0!1QA``C`'?`*V=%0#.P1``DFU%`#`"WP"M
M`=\`D15!`(R]$`",`=\`+TH5`*VT$`",(,`IK+T0`(P!WP#3S!``<P+?`(P`
M`">3@,`I<R#**(P"`";.`=\`D$#`*8Y@P"EL%@!<86#**'=`RBAC@,H"(```
M3/_7QE=CP/\"!`""`F$@P"G_5\574)O?%:]U,17-I8<548K.%!`FK@/O^;,#
MKF0@%*W!AP,Q!HP#$```%@\``!;.V9$##0``%I$``">0(,`ICT#`*8Y@P"F-
M@,`I@*#`*8#`P"F`X($I82#`*&-`P`(@``!,8\#^`GC@P"EYP,`I>J#`*7Q@
MP"EA(,$I=P#!*8R@P"B/P,`HSG1%`,TP+0"M`=\`K+$2`.^Q$`"0>``DS+T0
M`(V@P"F,P,`IF0`5`-H`%0"\`!4`F.#``@#:`$0,_(`"FH4`9'U`P"E=FT0`
M>X#`*;L#WP![&T$`O?^_`GX@P"F7`Q4`O@/?`)OO$````$`#XD(`+.&"`"S@
MP@`LXP(`+"0#%0`#`T`L`D-`+`&#0"SW`L$"`,-`+/];Z%?[UO]?O9M``-X;
M00!:`[\"G`/!`EIW$0#<\Q``>X#`*'U`P"A^(,`H1@,5`(4#%0`$`Q4`_T/%
M5SKC@2EA(,$H=P#!*'C@P"AYP,`H>J#`*'Q@P"AC0,$"(```3```0`,``$`#
M``!``P``0`,``$`#``!``Q<`@0+W0A$`S%P2`/>R$P#,,!,`]S(5``3#$`#F
M`A4`_^/$5RQ[`"0-`($"C%T0`"SC@2F-E?]?)`,5`%I?$0"<WQ``_Y_G5__G
M_E,``$`#8T#_`JR@P"AZ(,`I>P``)[HH`"2[,``DC`W(`'>`P"EX8,`I>4#`
M*6&@P"FYX,`"#P"^`EHS``![,P``C@6``B\S$#@-X(`"MP`5`)@`%0!:PTP`
M>\-,`"R[$`"N50%D#0"!`@\0@`*M.1$`KX4";`X(@`*N70)LH#D"1.0"%0#_
M$^=7X.+`*2`CP"D@0\`I(&/`*2"#P"D@H\`I(,/`*?O"@2GZTH$IY`(5`/_G
MYE?L`@`FY`(5`(QA10`,`P`I[`(`)HQ!10`,!P`I[`(`)HPA10`,"P`I[`(`
M)@P/`"GL(L`HC&%%``P3`"GL(L`HC$%%``P7`"GL(L`HC"%%``P;`"GL(L`H
M#!\`*>Q"P"B,844`#",`*>Q"P"B,044`#"<`*>Q"P"B,(44`#"L`*>Q"P"@,
M+P`I[&+`*(QA10`,,P`I[&+`*(Q!10`,-P`I[&+`*(PA10`,.P`I[&+`*`P_
M`"GL@L`HC&%%``Q#`"GL@L`HC$%%``Q'`"GL@L`HC"%%``Q+`"GL@L`H#$\`
M*6&@P"AW@,`H>&#`*'E`P"AZ(,`H>P``)F/`P`+_E\%3#>"``@^`@`*M.1$`
MK[4`;`Y`@`*NC0!L#B"``JYE`&P.$(`"KCT`;`X(@`*N%0!LO\'^0X`!`"G_
MN_Y3``!``X`!0"FM^?\"C`G``K^E_D/_Y_]3``!``P``0`,``$`#@`$`):WQ
M_P(."(`"C!'``J[!_VO_S_]3``!``P``0`.``0`GK>'_`@X0@`*,(<`"KIG_
M:__/_U,``$`#``!``X`!`">`(<`IK<'_`@X@@`*,0<`"KFW_:__+_U,``$`#
M(#L<.*V!_P(.0(`"@"'`*8!!P"F`8<`IC('``JX]_VO_P_]3``!``P``0`,`
M`$`#``!``P``0`,``$`#``!``X`!`"G_R_U3``!``P``0`,``$`#``!``P``
M0`,``$`#@`%`*:WY_P*,"<`"OZ']0__3_U,``$`#``!``P``0`,@.Q@XK?'_
M`@X(@`*,$<`"KGG]:__/_U-L`0`:AR'!*`P``!Z`@<%/```````````!``(`
M`````"5S+R5S````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?
M1'EN84QO861E<@``````26YT97)N86QS.CI005(Z.D)/3U0`````97AE````
M```O<')O8R\E:2\E<P``````+@````````!005)?5$5-4```````````4$%2
M7U!23T=.04U%`````#H`````````+P`````````E<R5S)7,``%!%4DPU3$E"
M``````````!015),3$E"`%!%4DPU3U!4``````````!015),24\``%!!4E])
M3DE424%,25I%1`!005)?4U!!5TY%1```````4$%27T-,14%.`````````%!!
M4E]$14)51P````````!005)?0T%#2$4`````````4$%27T=,3T)!3%]$14)5
M1P``````````4$%27T=,3T)!3%]435!$25(`````````4$%27U1-4$1)4@``
M`````%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.```````````Q
M`````````&QS965K(&9A:6QE9`````!R96%D(&9A:6QE9```````3$1?3$E"
M4D%265]0051(`%-94U1%30``+W1M<`````!54T52`````%5315).04U%````
M```````E,#)X`````'!A<BT`````)7,E<R5S)7,``````````"5S.B!C<F5A
M=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO
M/25I*0H````````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS
M869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO
M;BD*````````4$%42`````!P87)L`````"YP87(`````<VAO<G0@<F5A9```
M`````"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M
M)74M)74E<P``````````&`````````!P97)L`````#``````````4$%2.CI0
M86-K97(Z.E9%4E-)3TX`````,2XP-C,```!5;F%B;&4@=&\@8W)E871E(&-A
M8VAE(&1I<F5C=&]R>0``````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@
M8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``````
M````+64````````M+0```````%1-4$1)4@``5$5-4$1)4@!414U0`````%1-
M4```````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`
M(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K
M86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I
M>F4L("1C86-H95]N86UE7W-I>F4I.PI"14=)3B!["B1005)?34%'24,@/2`B
M7&Y005(N<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH
M(DXB*0HD8V%C:&5?;F%M95]S:7IE(#T@-#`["B102UI)4%]-04=)0R`](")0
M2UPP,#-<,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]
M($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@
M)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M
M,2D@)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT
M:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P*2!["G-E96L@
M)&9H+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L
M96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@
M)%!!4E]-04=)0RDI(#X](#`I('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S
M("T]("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP
M+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I
M9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q
M=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D
M=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*
M;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE
M.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI
M;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A
M<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&
M:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL
M93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M
M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE
M;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL
M="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A
M<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@
M*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO
M9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V
M+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@
M8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N
M86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I
M9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?
M:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@
M)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[
M)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/
M4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D
M7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O
M9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*
M7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D
M14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&
M24Q%7W-E8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]
M('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE
M*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=
M*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N
M<&T*;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G
M:6,H*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T
M(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O
M9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC
M(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P
M;W,@+2`D1DE,15]O9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I+"`P
M.PIR96%D(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F
M(&YE(")<,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@>PIO=71S*").
M;R!C86-H92!M87)K97(@9F]U;F0B*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q
M6T-A8VAE(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I
M8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L
M("1&24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@
M)&)U9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O
M9F9S970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?
M<VEZ92`M("1O9F9S970L(#`["B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T
M96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B
M1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F
M+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F
M=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL
M;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF
M7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X
M="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&
M2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I
M.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI
M>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT
M(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN
M86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL
M96YA;65](#T@)&9U;&QN86UE.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U
M;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^
M("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*
M<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H
M)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O
M<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T[
M"G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M
M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L
M92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE
M.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D
M:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E
M*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I
M.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A
M<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF
M:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE
M;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR
M971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T
M(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,
M;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V
M>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F
M:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL
M97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO
M*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F
M:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA
M;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I
M<F5?;&ES='LD9FEL96YA;65].PI]"FEF("@D8G5F(&YE("102UI)4%]-04=)
M0RD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@
M:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?
M<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@
M;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO
M9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5]
M.R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M
M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I
M;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB
M7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@
M('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%2
M1U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!
M4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A
M<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*
M)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S
M=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE
M;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q
M(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q
M(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD
M8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L
M92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*
M?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O
M<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS
M:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!
M4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D
M14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!
M4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H
M:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U
M:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$
M:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP
M.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D
M<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=
M.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP
M+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E
M861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D
M;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-
M151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]
M?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG
M.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A
M=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B
M.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P
M87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?
M34%'24,["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\
M($E/.CI&:6QE.CI/7U)$5U(H*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W
M-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=
M.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97([
M"FEF("AD969I;F5D("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?
M1D@L("1L;V%D97(L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS92![
M"FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%
M3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M
M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL
M=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R
M:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T
M;R`B)&]U="(Z("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE
M879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC
M*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$
M4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D
M0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z
M.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\
M?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`
M1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM
M>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@
M("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A
M8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N
M86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*
M?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^
M(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME
M>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO
M*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH
M)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D
M9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*
M;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT
M(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N
M9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ
M<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[
M;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI
M('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O
M(#T@=6YD968["F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@
M<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X[
M"F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O
M;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE
M;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z
M.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.
M)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R
M;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S
M*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II
M<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:
M7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T
M(ET["GT*:68@*"1M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#
M3$5!3B(I.PI]"F5L<V4@>PII9B`H(61E9FEN960@)&-A8VAE7VYA;64I('L*
M;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@)&9H+"`P+"`P
M.PHD8W1X+3YA9&1F:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?
M;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T
M<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA
M;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H
M95]N86UE*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*
M?0IM>2`D;V9F<V5T(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I.PHD
M9F@M/G!R:6YT*'!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F
M:"T^8VQO<V4@;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B
M)&]U="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@
M=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR
M97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI[
M"G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD
M;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D
M;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP
M+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP
M(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK
M4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD
M4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C
M=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@
M(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE
M;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$
M:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE
M.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH
M/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*
M;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ
M4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D[
M"FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP
M<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M
M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D[
M"GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T
M;R`B)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.
M86UE9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R
M(&1I92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T
M7VYA;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H
M<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M
M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!
M;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@
M6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP
M87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H
M:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`
M7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A
M=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@
M*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK
M<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W
M:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB
M.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER
M92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q
M=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO
M.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*
M<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I
M;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR
M97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@
M0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E
M($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y
M.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q
M=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![
M(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL
M('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE
M=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L
M('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*
M979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*
M:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!]
M(#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A
M8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!4
M35!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@
M+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T
M:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L
M('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF
M("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]
M("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@
M>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%
M3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@
M)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J
M(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H
M95]D:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T
M96UP+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G
M;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII
M9B`H*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P
M*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*
M+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B
M=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!E<2`B7#!#04-(12(I
M('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM
M(&QE;F=T:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A
M9"`D9F@L("1B=68L("1C86-H95]N86UE7W-I>F4["B1B=68@/7X@<R]<,"\O
M9SL*)&-A8VAE7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*
M?0II9B`H(21C86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*
M)$5.5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L
M:6U])&-A8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!
M4E]414U0?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF
M("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\[
M"GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E
M*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL
M97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M
M92XD)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I
M"B8F("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D
M;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M
M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T
M=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I
M;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345]
M(#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]
M("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@
M)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P
M<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I
M.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M
M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG
M+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P
M<F]G;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5]
M.PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[
M<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%
M3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER
M(#U^(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I
M<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@
M+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D
M<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T
M*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@
M7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]0
M4D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@
M/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*
M?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T
M8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E
M=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O
M7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\[
M"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I
M;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I
M('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R
M.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!0
M4D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ
M=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B
M?2`]("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%2
M7T=,3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@
M)$5.5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U
M:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS
M92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@
M0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z
M.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R
M8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI
M.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@
M7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@
M<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B
M.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O
M9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^
M+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?
M7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?
M15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/
M4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@!P97)L>'-I+F,`````````
M`$-!0TA%``#_____`````/____\``````1L#.^P````<````D(#__U0&``"`
M@O__!`$``!"$__\8`0``((7__W`!``"XA?__G`$``("'___\`0``((K__UP"
M``!0B___L`(``*B+___0`@``R(O__^0"``"@C/__'`,``*B,__\P`P``$(__
M_Z`#``!(C___P`,``."0__\D!```>)7__U0$``#@E?__>`0``$B6__^0!```
MV)?__]@$````F/__]`0``/B8__](!0``<)___]0%``#(H?__#`8``/"B__^(
M!@``<+G__[`&``#@N?__T`8``&"[__\4!P``:+[__U`'````````$```````
M```!>E(``7@!`1L-`P`0````&````'2!__]@``````<!`%0````L````\(+_
M_Q`!````1`Y`5)<"@0&="%R9!)H%FP9XF`.<!WC81-E$VD3;1-Q$P43=2-=$
M#@!8#D"!`9<"F`.9!)H%FP:<!YT(6-C<3-E$VD3;```H````A````*B#__^8
M`````$0.L`%,EP*8`X$!`G0*P4371-A$#@!$"P```%P```"P````%(3__\0!
M````1`[``4B9!($!7)<"3-=0P4391`X`3`[``8$!EP*9!$28`U":!0)4FP8"
M>-M<"M=$V$3:7`M@FP9,U]C:VU"7`I@#F@6;!D3:VT371-@``%P````0`0``
M?(7__YP"````1`Y@9)<"F`.9!)L&@0&:!9P'G0@#&`$*P4371-A$V43:1-M$
MW$3=1`X`4`L"4)X)GPH">`K>1-]4"V#>WTB>"9\*3-[?2)X)GPI(WD3?`%``
M``!P`0``O(?__RP!````1`Y`5)<"F`.9!)H%@0%4#L`@>)L&>-L"1`Y`1,%$
MUT381-E$VD0.`%@.P""!`9<"F`.9!)H%FP9$VT@*FP9$"T2;!AP```#$`0``
MF(C__U@`````1`X02)<"@0%LP4376`X`$````.0!``#0B/__(``````````T
M````^`$``-R(___8`````$0.4%2!`9<"F`.9!)H%5`[00`*("@Y01,%(UT38
M1-E$VD0.`$0+`!`````P`@``?(G__P0`````````;````$0"``!PB?__9`(`
M``!$#N`!6)<"F`.9!)L&@0%,#N`A`E0*#N`!1,%$UT381-E$VT0.`%0+4)H%
MG`>>"62="`+<"MI$W$3=1-Y$"P)HVD3<1-U$WD2:!9P'G@E$VD3<1-Y4F@6<
M!YT(G@D``!P```"T`@``:(O__S@`````1`X03)<"@0%8P4C71`X`8````-0"
M``"`B___E`$```!$#C!(F02!`50.L"!0F`-,EP("E-=$V$0.,$3!1-E$#@!$
M#K`@@0&8`YD$1-A8#C!$P4391`X`6`ZP(($!EP*8`YD$`E`*UT382`M$U]A(
MEP*8`RP````X`P``M(S__Y0$````1`XP4)<"F`.9!($!`T`$"L%$UT381-E,
M#@!$"P```"````!H`P``')'__V0`````1`X@2)<"@0$"2`K!1-=$#@!$"Q0`
M``",`P``8)'__V0`````1`Y@1($)`$0```"D`P``L)'__XP!````1`Y@:)<"
MF`.9!)H%FP:<!YT(G@F!`4P.X(`$`N@*#F!$P4371-A$V43:1-M$W$3=1-Y$
M#@!@"Q@```#L`P``^)+__R0`````1`X01($!5,%$#@!0````"`0```23___T
M`````$0.0$R8`YD$@0%LEP),UUC!1-A$V40.`$0.0($!EP*8`YD$2)H%`DS:
M1,%$V$392-=(#@!$#D"!`9@#F01(EP*:!0"(````7`0``*B3__]X!@```$0.
MH`-HF`.9!)H%@0&7`@)PFP:<!YT(`[0!"L%$W$3=1-=$V$391-I(VT0.`$0+
M`]P`G@E(W@(\V]S=5,%$V$391-I(UT0.`$0.H`.!`9<"F`.9!)H%FP:<!YT(
MG@D#7`$*WE0+`R0!WD2>"43;W-W>4)L&G`>=")X)`#0```#H!```E)G__U0"
M````1`Y`6)<"F02:!8$!F`.;!@.4`0K!1-=$V$391-I$VT0.`%@+````1```
M`"`%``"TF___&`$```!$#C!,EP*8`X$!`E`*P4371-A$#@!<"TB9!'C98)D$
M4-E$P4372-A$#@!$#C"!`9<"F`-$F00`,````&@%```T>O__[`$```!$#F!4
M@0&8`Y<"F02:!0-(`0K!1-=$V$3:2-E$#@!$"P```"0```"<!0``8)S__X`6
M````4`Z@!4R!`9<"`U06"L%$UT0.`$0+```<````Q`4``+BR__]P`````$0.
M$$B!`0)<P40.`````$````#D!0``"+/__WP!````1`Y0`D28`YD$F@6<!X$!
MEP)@G0A(FP90G@D"7-M$W43>6`K!1-=$V$391-I$W$0.`%P+.````"@&``!$
MM/__"`,```!$#C!,F@6;!ER7`I@#F02!`0-H`0K!1-=$V$391-I$VT0.`$0+
M````````$````&0&```0M___$```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````H(````````-`?`````````0````````#>
M`@````````$`````````[@(````````!`````````/@"````````&0``````
M``#0^P```````!L`````````"``````````:`````````-C[````````'```
M```````(`````````/7^_V\`````J`(````````%`````````+`,````````
M!@````````"``P````````H`````````1`0````````+`````````!@`````
M````%0````````````````````,`````````T/T````````"`````````$`%
M````````%``````````'`````````!<`````````V!,````````'````````
M`/@1````````"`````````#@`0````````D`````````&``````````>````
M`````!@`````````^___;P`````!```(`````/[__V\`````N!$```````#_
M__]O``````(`````````\/__;P````#T$````````/G__V\`````"0``````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````/__________
M```````````@&0```````"`9````````(!D````````@&0```````"`9````
M````(!D````````@&0```````"`9````````(!D````````@&0```````"`9
M````````(!D````````@&0```````"`9````````(!D````````@&0``````
M`"`9````````(!D````````@&0```````"`9````````(!D````````@&0``
M`````"`9````````(!D````````@&0```````"`9````````(!D````````@
M&0```````"`9````````(!D````````@&0```````"`9````````(!D`````
M```@&0```````"`9````````(!D````````@&0```````"`9````````(!D`
M```````@&0```````"`9````````(!D````````@&0```````"`9````````
M(!D````````@&0```````"`9````````(!D````````@&0```````"`9````
M````(!D````````@&0```````"`9````````(!D````````@&0```````"`9
M````````X/L`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````"E!!4BYP;0H``````````!!<````````>%X```````"`
M7@```````(A>````````D%X``````````````````)A>````````2``!````
M``!'0T,Z("A$96)I86X@,30N,BXP+38I(#$T+C(N,```+G-H<W1R=&%B`"YI
M;G1E<G``+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH
M87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N
M7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N=&5X=``N<F]D871A`"YE:%]F<F%M
M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA
M;6EC`"YG;W0`+F1A=&$`+G-D871A`"YB<W,`+F-O;6UE;G0`````````````
M````````````````````````````````````````````````````````````
M````````````````````"P````$````"`````````#@"````````.`(`````
M```E`````````````````````0```````````````````!,````'`````@``
M``````!@`@```````&`"````````)`````````````````````0`````````
M```````````F````!P````(`````````A`(```````"$`@```````"``````
M```````````````$````````````````````-````/;__V\"`````````*@"
M````````J`(```````#4``````````4`````````"```````````````````
M`#X````+`````@````````"``P```````(`#````````,`D````````&````
M!P````@`````````&`````````!&`````P````(`````````L`P```````"P
M#````````$0$```````````````````!````````````````````3@```/__
M_V\"`````````/00````````]!````````#$``````````4``````````@``
M```````"`````````%L```#^__]O`@````````"X$0```````+@1````````
M0``````````&`````@````@```````````````````!J````!`````(`````
M````^!$```````#X$0```````.`!````````!0`````````(`````````!@`
M````````=`````0```!"`````````-@3````````V!,```````!`!0``````
M``4````3````"``````````8`````````'D````!````!@`````````@&0``
M`````"`9````````H`,``````````````````!``````````$`````````!^
M`````0````8`````````P!P```````#`'````````.@]````````````````
M```@````````````````````A`````$````"`````````+!:````````L%H`
M``````"`00``````````````````$````````````````````(P````!````
M`@`````````PG````````#"<````````[`````````````````````0`````
M``````````````":`````0````(`````````()T````````@G0```````'@&
M```````````````````(````````````````````I`````X````#````````
M`-#[````````T+L````````(````````````````````"``````````(````
M`````+`````/`````P````````#8^P```````-B[````````"```````````
M``````````@`````````"`````````"\````!@````,`````````X/L`````
M``#@NP```````/`!````````!@`````````(`````````!``````````Q0``
M``$````#`````````-#]````````T+T````````P`@``````````````````
M"``````````(`````````,H````!`````P````````````$```````#`````
M````2`````````````````````@```````````````````#0`````0````,`
M````````2``!``````!(P`````````@````````````````````(````````
M````````````UP````@````#`````````%```0``````4,`````````H````
M````````````````"````````````````````-P````!````,```````````
M`````````%#`````````'@````````````````````$``````````0``````
M```!`````P````````````````````````!NP````````.4`````````````
5```````!````````````````````
